#!/usr/bin/env python
# -*- coding: iso-8859-1 -*-

## Copyright 1999-2003 by LivingLogic AG, Bayreuth, Germany.
## Copyright 1999-2003 by Walter Drwald
##
## All Rights Reserved
##
## Permission to use, copy, modify, and distribute this software and its documentation
## for any purpose and without fee is hereby granted, provided that the above copyright
## notice appears in all copies and that both that copyright notice and this permission
## notice appear in supporting documentation, and that the name of LivingLogic AG or
## the author not be used in advertising or publicity pertaining to distribution of the
## software without specific, written prior permission.
##
## LIVINGLOGIC AG AND THE AUTHOR DISCLAIM ALL WARRANTIES WITH REGARD TO THIS SOFTWARE,
## INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL
## LIVINGLOGIC AG OR THE AUTHOR BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL
## DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER
## IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR
## IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.

"""
<doc:par>A module that allows you to embed tags from
the <a href="http://jakarta.apache.org/struts/">Struts</a>
html custom tag library.</doc:par>
"""

__version__ = "$Revision: 2.8.6.2 $"[11:-2]
# $Source: /data/cvsroot/LivingLogic/xist/_xist/ns/struts_html.py,v $

from ll.xist import xsc

class Element(xsc.Element):
	"""
	common base class for all the struts html elements
	"""
	publishPrefix = 1

class taglib(xsc.ProcInst):
	"""
	creates a standard struts taglib header
	"""
	def publish(self, publisher):
		publisher.publish(u'<%@ taglib uri="/WEB-INF/struts-html.tld" prefix="struts_html" %>')

class PartMouseElement(Element):
	attrHandlers = {
		"onblur": xsc.TextAttr,
		"onchange": xsc.TextAttr,
		"onclick": xsc.TextAttr,
		"ondblclick": xsc.TextAttr,
		"onfocus": xsc.TextAttr,
		"onkeydown": xsc.TextAttr,
		"onkeypress": xsc.TextAttr,
		"onkeyup": xsc.TextAttr,
		"onmousedown": xsc.TextAttr,
		"onmousemove": xsc.TextAttr,
		"onmouseout": xsc.TextAttr,
		"onmouseover": xsc.TextAttr,
		"onmouseup": xsc.TextAttr,
		"style": xsc.TextAttr,
		"styleClass": xsc.TextAttr,
		"alt": xsc.TextAttr,
		"altKey": xsc.TextAttr,
		"title": xsc.TextAttr,
		"titleKey": xsc.TextAttr,
		"value": xsc.TextAttr,
		"property": xsc.TextAttr,
		"styleId": xsc.TextAttr
	}

class MouseElement(PartMouseElement):
	attrHandlers = PartMouseElement.attrHandlers.copy()
	attrHandlers.update({"accesskey": xsc.TextAttr, "tabindex": xsc.TextAttr, "disabled": xsc.TextAttr})

class base(Element):
	"""
	Render an HTML base-Element
	"""
	empty = True
	attrHandlers = {
		"target": xsc.URLAttr,
		"server": xsc.TextAttr
	}

class button(MouseElement):
	"""
	Render A Button Input Field
	"""
	empty = False
	attrHandlers = MouseElement.attrHandlers.copy()
	attrHandlers["indexed"] = xsc.TextAttr

class cancel(MouseElement):
	"""
	Render a Cancel Button
	"""
	empty = False

class checkbox(MouseElement):
	"""
	Render A Checkbox Input Field
	"""
	empty = False
	attrHandlers = MouseElement.attrHandlers.copy()
	attrHandlers["indexed"] = xsc.TextAttr
	attrHandlers["name"] = xsc.TextAttr

class errors(Element):
	"""
	Conditionally display a set of accumulated error messages.
	"""
	empty = True
	attrHandlers = {
		"bundle": xsc.TextAttr,
		"locale": xsc.TextAttr,
		"name": xsc.TextAttr,
		"property": xsc.TextAttr
	}

class file(MouseElement):
	"""
	Render A File Select Input Field
	"""
	empty = False
	attrHandlers = MouseElement.attrHandlers.copy()
	attrHandlers["accept"] = xsc.TextAttr
	attrHandlers["indexed"] = xsc.TextAttr
	attrHandlers["maxlength"] = xsc.TextAttr
	attrHandlers["name"] = xsc.TextAttr
	attrHandlers["size"] = xsc.TextAttr

class form(Element):
	"""
	Define An Input Form
	"""
	empty = False
	attrHandlers = {
		"action": xsc.TextAttr,
		"enctype": xsc.TextAttr,
		"focus": xsc.TextAttr,
		"focusIndex": xsc.TextAttr,
		"method": xsc.TextAttr,
		"name": xsc.TextAttr,
		"onreset": xsc.TextAttr,
		"onsubmit": xsc.TextAttr,
		"scope": xsc.TextAttr,
		"style": xsc.TextAttr,
		"styleClass": xsc.TextAttr,
		"styleId": xsc.TextAttr,
		"target": xsc.TextAttr,
		"type": xsc.TextAttr
	}

class frame(Element):
	"""
	Render an HTML frame element
	"""
	empty = False
	attrHandlers = {
		"action": xsc.TextAttr,
		"anchor": xsc.TextAttr,
		"forward": xsc.TextAttr,
		"frameborder": xsc.TextAttr,
		"frameName": xsc.TextAttr,
		"href": xsc.URLAttr,
		"longdesc": xsc.TextAttr,
		"marginheight": xsc.TextAttr,
		"marginwidth": xsc.TextAttr,
		"name": xsc.TextAttr,
		"noresize": xsc.TextAttr,
		"page": xsc.TextAttr,
		"paramId": xsc.TextAttr,
		"paramName": xsc.TextAttr,
		"paramProperty": xsc.TextAttr,
		"paramScope": xsc.TextAttr,
		"property": xsc.TextAttr,
		"scope": xsc.TextAttr,
		"scrolling": xsc.TextAttr,
		"style": xsc.TextAttr,
		"styleClass": xsc.TextAttr,
		"styleId": xsc.TextAttr,
		"title": xsc.TextAttr,
		"titleKey": xsc.TextAttr,
		"transaction": xsc.TextAttr
	}

class hidden(PartMouseElement):
	"""
	Render A Hidden Field
	"""
	empty = False
	attrHandlers = PartMouseElement.attrHandlers.copy()
	attrHandlers["accesskey"] = xsc.TextAttr
	attrHandlers["indexed"] = xsc.TextAttr
	attrHandlers["name"] = xsc.TextAttr
	attrHandlers["write"] = xsc.TextAttr

class html(Element):
	"""
	Render an HTML html-Element
	"""
	empty = False
	attrHandlers = {"locale": xsc.TextAttr}
	attrHandlers["xhtml"] = xsc.TextAttr

class image(MouseElement):
	"""
	Render an input tag of type "image"
	"""
	empty = False
	attrHandlers = MouseElement.attrHandlers.copy()
	attrHandlers["align"] = xsc.TextAttr
	attrHandlers["border"] = xsc.TextAttr
	attrHandlers["bundle"] = xsc.TextAttr
	attrHandlers["indexed"] = xsc.TextAttr
	attrHandlers["locale"] = xsc.TextAttr
	attrHandlers["page"] = xsc.TextAttr
	attrHandlers["pageKey"] = xsc.TextAttr
	attrHandlers["src"] = xsc.TextAttr
	attrHandlers["srcKey"] = xsc.TextAttr

class img(Element):
	"""
	Render an HTML img tag
	"""
	empty = True
	attrHandlers = {
		"align": xsc.TextAttr,
		"alt": xsc.TextAttr,
		"altKey": xsc.TextAttr,
		"border": xsc.TextAttr,
		"bundle": xsc.TextAttr,
		"height": xsc.TextAttr,
		"hspace": xsc.TextAttr,
		"imageName": xsc.TextAttr,
		"ismap": xsc.TextAttr,
		"locale": xsc.TextAttr,
		"lowsrc": xsc.TextAttr,
		"name": xsc.TextAttr,
		"onclick": xsc.TextAttr,
		"ondblclick": xsc.TextAttr,
		"onkeydown": xsc.TextAttr,
		"onkeypress": xsc.TextAttr,
		"onkeyup": xsc.TextAttr,
		"onmousedown": xsc.TextAttr,
		"onmousemove": xsc.TextAttr,
		"onmouseout": xsc.TextAttr,
		"onmouseover": xsc.TextAttr,
		"onmouseup": xsc.TextAttr,
		"paramId": xsc.TextAttr,
		"page": xsc.TextAttr,
		"pageKey": xsc.TextAttr,
		"paramName": xsc.TextAttr,
		"paramProperty": xsc.TextAttr,
		"paramScope": xsc.TextAttr,
		"property": xsc.TextAttr,
		"scope": xsc.TextAttr,
		"src": xsc.TextAttr,
		"srcKey": xsc.TextAttr,
		"style": xsc.TextAttr,
		"styleClass": xsc.TextAttr,
		"styleId": xsc.TextAttr,
		"title": xsc.TextAttr,
		"titleKey": xsc.TextAttr,
		"usemap": xsc.TextAttr,
		"vspace": xsc.TextAttr,
		"width": xsc.TextAttr
	}

class javascript(Element):
	"""
	Render JavaScript validation based on the validation rules loaded by the ValidatorPlugIn.
	"""
	empty = True
	attrHandlers = {
		"cdata": xsc.TextAttr,
		"dynamicJavascript": xsc.TextAttr,
		"formName": xsc.TextAttr,
		"method": xsc.TextAttr,
		"page": xsc.TextAttr,
		"src": xsc.TextAttr,
		"staticJavascript": xsc.TextAttr,
		"htmlComment": xsc.TextAttr
	}

class link(Element):
	"""
	Render an HTML anchor or hyperlink
	"""
	empty = False
	attrHandlers = {
		"accesskey": xsc.TextAttr,
		"action": xsc.TextAttr,
		"anchor": xsc.TextAttr,
		"forward": xsc.TextAttr,
		"href": xsc.URLAttr,
		"indexed": xsc.TextAttr,
		"indexId": xsc.TextAttr,
		"linkName": xsc.TextAttr,
		"name": xsc.TextAttr,
		"onblur": xsc.TextAttr,
		"onclick": xsc.TextAttr,
		"ondblclick": xsc.TextAttr,
		"onfocus": xsc.TextAttr,
		"onkeydown": xsc.TextAttr,
		"onkeypress": xsc.TextAttr,
		"onkeyup": xsc.TextAttr,
		"onmousedown": xsc.TextAttr,
		"onmousemove": xsc.TextAttr,
		"onmouseout": xsc.TextAttr,
		"onmouseover": xsc.TextAttr,
		"onmouseup": xsc.TextAttr,
		"page": xsc.TextAttr,
		"paramId": xsc.TextAttr,
		"paramName": xsc.TextAttr,
		"paramProperty": xsc.TextAttr,
		"paramScope": xsc.TextAttr,
		"property": xsc.TextAttr,
		"scope": xsc.TextAttr,
		"style": xsc.TextAttr,
		"styleClass": xsc.TextAttr,
		"styleId": xsc.TextAttr,
		"tabindex": xsc.TextAttr,
		"target": xsc.TextAttr,
		"title": xsc.TextAttr,
		"titleKey": xsc.TextAttr,
		"transaction": xsc.TextAttr
	}

class messages(Element):
	"""
	Conditionally display a set of accumulated messages.
	"""
	empty = False
	attrHandlers = {
		"id": xsc.TextAttr,
		"bundle": xsc.TextAttr,
		"locale": xsc.TextAttr,
		"name": xsc.TextAttr,
		"property": xsc.TextAttr,
		"header": xsc.TextAttr,
		"footer": xsc.TextAttr,
		"message": xsc.TextAttr
	}

class multibox(MouseElement):
	"""
	Render A Checkbox Input Field
	"""
	empty = False
	attrHandlers = MouseElement.attrHandlers.copy()
	attrHandlers["name"] = xsc.TextAttr

class option(Element):
	"""
	Render A Select Option
	"""
	empty = False
	attrHandlers = {
		"bundle": xsc.TextAttr,
		"disabled": xsc.TextAttr,
		"key": xsc.TextAttr,
		"locale": xsc.TextAttr,
		"style": xsc.TextAttr,
		"styleId": xsc.TextAttr,
		"styleClass": xsc.TextAttr,
		"value": xsc.TextAttr
	}

class options(Element):
	"""
	Render a Collection of Select Options
	"""
	empty = True
	attrHandlers = {
		"collection": xsc.TextAttr,
		"filter": xsc.TextAttr,
		"labelName": xsc.TextAttr,
		"labelProperty": xsc.TextAttr,
		"name": xsc.TextAttr,
		"property": xsc.TextAttr,
		"style": xsc.TextAttr,
		"styleClass": xsc.TextAttr
	}

class optionsCollection(Element):
	"""
	Render a Collection of Select Options
	"""
	empty = True
	attrHandlers = {
		"filter": xsc.TextAttr,
		"label": xsc.TextAttr,
		"name": xsc.TextAttr,
		"property": xsc.TextAttr,
		"style": xsc.TextAttr,
		"styleClass": xsc.TextAttr,
		"value": xsc.TextAttr
	}

class password(MouseElement):
	"""
	Render A Password Input Field
	"""
	empty = False
	attrHandlers = MouseElement.attrHandlers.copy()
	attrHandlers["indexed"] = xsc.TextAttr
	attrHandlers["maxlength"] = xsc.TextAttr
	attrHandlers["name"] = xsc.TextAttr
	attrHandlers["readonly"] = xsc.TextAttr
	attrHandlers["redisplay"] = xsc.TextAttr
	attrHandlers["size"] = xsc.TextAttr

class radio(MouseElement):
	"""
	Render A Radio Button Input Field
	"""
	empty = False
	attrHandlers = MouseElement.attrHandlers.copy()
	attrHandlers["indexed"] = xsc.TextAttr
	attrHandlers["name"] = xsc.TextAttr
	attrHandlers["idName"] = xsc.TextAttr

class reset(MouseElement):
	"""
	Render A Reset Button Input Field
	"""
	empty = False

class rewrite(Element):
	"""
	Render an URI
	"""
	empty = True
	attrHandlers = {
		"anchor": xsc.TextAttr,
		"forward": xsc.TextAttr,
		"href": xsc.URLAttr,
		"name": xsc.TextAttr,
		"page": xsc.TextAttr,
		"paramId": xsc.TextAttr,
		"paramName": xsc.TextAttr,
		"paramProperty": xsc.TextAttr,
		"paramScope": xsc.TextAttr,
		"property": xsc.TextAttr,
		"scope": xsc.TextAttr,
		"transaction": xsc.TextAttr
	}

class select(PartMouseElement):
	"""
	Render A Select Element
	"""
	empty = False
	attrHandlers = PartMouseElement.attrHandlers.copy()
	attrHandlers["disabled"] = xsc.TextAttr
	attrHandlers["indexed"] = xsc.TextAttr
	attrHandlers["multiple"] = xsc.TextAttr
	attrHandlers["name"] = xsc.TextAttr
	attrHandlers["tabindex"] = xsc.TextAttr
	attrHandlers["size"] = xsc.TextAttr

class submit(MouseElement):
	"""
	Render A Submit Button
	"""
	empty = False
	attrHandlers = MouseElement.attrHandlers.copy()
	attrHandlers["indexed"] = xsc.TextAttr

class text(MouseElement):
	"""
	Render An Input Field of Type text
	"""
	empty = False
	attrHandlers = MouseElement.attrHandlers.copy()
	attrHandlers["indexed"] = xsc.TextAttr
	attrHandlers["maxlength"] = xsc.TextAttr
	attrHandlers["name"] = xsc.TextAttr
	attrHandlers["readonly"] = xsc.TextAttr
	attrHandlers["size"] = xsc.TextAttr

class textarea(MouseElement):
	"""
	Render A Textarea
	"""
	empty = False
	attrHandlers = MouseElement.attrHandlers.copy()
	attrHandlers["cols"] = xsc.TextAttr
	attrHandlers["indexed"] = xsc.TextAttr
	attrHandlers["name"] = xsc.TextAttr
	attrHandlers["readonly"] = xsc.TextAttr
	attrHandlers["rows"] = xsc.TextAttr

class xhtml(Element):
	"""
	Render HTML tags as XHTML
	"""
	empty = True

namespace = xsc.Namespace("struts_html", "http://jakarta.apache.org/struts/tags-html", vars())

